pushex v0.2.3 Pushex.APNS.App View Source
Pushex.APNS.App represents an APNS application.
:name is a unique identifier used to find the application,
:certfile is the certificate for the application, and :env is :dev or :prod.
Pushex.APNS.App represents an APNS application.
:name is a unique identifier used to find the application,
:certfile is the certificate for the application, and :env is :dev or :prod.