pushex v0.2.1 Pushex.GCM.Request View Source
Pushex.GCM.Request represents a request that will be sent to GCM.
It contains the notification, and all the metadata that can be sent with it.
Only the key with a value will be sent to GCM, so that the proper default are used.